import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { useTsp } from "@typespec/emitter-framework";
import { FunctionDeclaration, TypeExpression } from "@typespec/emitter-framework/typescript";
import * as cl from "@typespec/http-client";
import { reportDiagnostic } from "../lib.js";
import { getClientcontextDeclarationRef } from "./client-context/client-context-declaration.js";
import { HttpRequest } from "./http-request.js";
import { HttpResponse } from "./http-response.js";
import { OperationPipeline } from "./operation-handlers/operation-pipeline.js";
import { PaginatedOperationHandler } from "./operation-handlers/paging/paginated-operation-handler.js";
import { OperationOptionsDeclaration } from "./operation-options.js";
import { getOperationParameters } from "./operation-parameters.js";
export function ClientOperations(props) {
  const namePolicy = ts.useTSNamePolicy();
  const clientOperations = props.client.operations;
  const fileName = namePolicy.getName(props.client.name + "Operations", "variable");
  if (clientOperations.length === 0) {
    return null;
  }
  return _$createComponent(ts.SourceFile, {
    path: `${fileName}.ts`,
    get children() {
      return _$createComponent(ay.For, {
        each: clientOperations,
        children: operation => _$createComponent(OperationPipeline, {
          get httpOperation() {
            return operation.httpOperation;
          },
          pipeline: {
            handlers: [PaginatedOperationHandler]
          }
        })
      });
    }
  });
}
export function ClientOperation(props) {
  const {
    $
  } = useTsp();
  const clientLibrary = cl.useClientLibrary();
  const client = clientLibrary.getClientForOperation(props.httpOperation);
  if (!client) {
    reportDiagnostic($.program, {
      code: "client-not-found",
      target: props.httpOperation.operation
    });
    return;
  }
  const returnType = $.httpOperation.getReturnType(props.httpOperation);
  const responseRefkey = ay.refkey(props.httpOperation, "http-response");
  const clientContextInterfaceRef = getClientcontextDeclarationRef(client);
  const signatureParams = [{
    name: "client",
    type: clientContextInterfaceRef,
    refkey: ay.refkey(client, "client")
  }, ...getOperationParameters(props.httpOperation)];
  return _$createComponent(ay.List, {
    hardline: true,
    get children() {
      return [_$createComponent(OperationOptionsDeclaration, {
        get operation() {
          return props.httpOperation;
        }
      }), _$createComponent(FunctionDeclaration, {
        get ["export"]() {
          return !props.internal;
        },
        async: true,
        get type() {
          return props.httpOperation.operation;
        },
        get returnType() {
          return _$createComponent(TypeExpression, {
            type: returnType
          });
        },
        parametersMode: "replace",
        parameters: signatureParams,
        get refkey() {
          return props.refkey;
        },
        get children() {
          return _$createComponent(ay.List, {
            hardline: true,
            get children() {
              return [_$createComponent(HttpRequest, {
                get httpOperation() {
                  return props.httpOperation;
                },
                responseRefkey: responseRefkey
              }), _$createComponent(HttpResponse, {
                get httpOperation() {
                  return props.httpOperation;
                },
                responseRefkey: responseRefkey
              })];
            }
          });
        }
      }), ";"];
    }
  });
}