import { createComponent as _$createComponent, createIntrinsic as _$createIntrinsic } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { useTsp } from "@typespec/emitter-framework";
import { ClassMethod } from "@typespec/emitter-framework/typescript";
import { useClientLibrary } from "@typespec/http-client";
import { flattenClients } from "../utils/client-discovery.js";
import { buildClientParameters } from "../utils/parameters.js";
import { getClientcontextDeclarationRef } from "./client-context/client-context-declaration.js";
import { getClientContextFactoryRef } from "./client-context/client-context-factory.js";
import { getOperationParameters } from "./operation-parameters.js";
export function Client(props) {
  const {
    $
  } = useTsp();
  const namePolicy = ts.useTSNamePolicy();
  const {
    topLevel
  } = useClientLibrary();
  return _$createComponent(ay.For, {
    each: topLevel,
    hardline: true,
    children: client => {
      const fileName = namePolicy.getName($.client.getName(client), "variable");
      const flatClients = flattenClients(client);
      return _$createComponent(ts.SourceFile, {
        path: `${fileName}.ts`,
        get children() {
          return _$createComponent(ay.For, {
            each: flatClients,
            hardline: true,
            children: client => _$createComponent(ClientClass, {
              client: client
            })
          });
        }
      });
    }
  });
}
export function getClientClassRef(client) {
  return ay.refkey(client.type, "client-class");
}
function getClientContextFieldRef(client) {
  return ay.refkey(client.type, "client-context");
}
export function ClientClass(props) {
  const {
    $
  } = useTsp();
  const namePolicy = ts.useTSNamePolicy();
  const clientName = namePolicy.getName($.client.getName(props.client), "class");
  const contextMemberRef = getClientContextFieldRef(props.client);
  const contextDeclarationRef = getClientcontextDeclarationRef(props.client);
  const clientClassRef = getClientClassRef(props.client);
  const subClients = props.client.subClients;
  const operations = props.client.operations;
  return _$createComponent(ts.ClassDeclaration, {
    "export": true,
    name: clientName,
    refkey: clientClassRef,
    get children() {
      return _$createComponent(ay.List, {
        hardline: true,
        get children() {
          return [_$createComponent(ts.ClassField, {
            name: "context",
            jsPrivate: true,
            refkey: contextMemberRef,
            type: contextDeclarationRef
          }), _$createComponent(ay.For, {
            each: subClients,
            hardline: true,
            semicolon: true,
            children: subClient => _$createComponent(SubClientClassField, {
              client: subClient
            })
          }), _$createComponent(ClientConstructor, {
            get client() {
              return props.client;
            }
          }), _$createComponent(ay.For, {
            each: operations,
            hardline: true,
            semicolon: true,
            children: op => {
              const parameters = getOperationParameters(op.httpOperation);
              const args = parameters.flatMap(p => p.refkey);
              const isPaging = Boolean($.operation.getPagingMetadata(op.httpOperation.operation));
              return _$createComponent(ClassMethod, {
                async: !isPaging,
                get type() {
                  return op.httpOperation.operation;
                },
                parameters: parameters,
                returnType: null,
                parametersMode: "replace",
                get children() {
                  return ["return", " ", _$createComponent(ts.FunctionCallExpression, {
                    get target() {
                      return ay.refkey(op.httpOperation.operation);
                    },
                    get args() {
                      return [contextMemberRef, ...args];
                    }
                  }), ";"];
                }
              });
            }
          })];
        }
      });
    }
  });
}
function getSubClientClassFieldRef(client) {
  return ay.refkey(client.type, "client-field");
}
function SubClientClassField(props) {
  const {
    $
  } = useTsp();
  const parent = props.client.parent;
  // If sub client has different parameters than client, don't add it as a subclass field
  // Todo: We need to detect the extra parameters and make this field a factory for the subclient
  if (parent && !$.client.haveSameConstructor(props.client, parent)) {
    return null;
  }
  const namePolicy = ts.useTSNamePolicy();
  const fieldName = namePolicy.getName($.client.getName(props.client), "class");
  const subClientClassRef = getClientClassRef(props.client);
  const subClientFieldRef = getSubClientClassFieldRef(props.client);
  return _$createComponent(ts.ClassField, {
    name: fieldName,
    type: subClientClassRef,
    refkey: subClientFieldRef
  });
}
function ClientConstructor(props) {
  const {
    $
  } = useTsp();
  const subClients = props.client.subClients.filter(sc => $.client.haveSameConstructor(sc, props.client));
  const clientContextFieldRef = getClientContextFieldRef(props.client);
  const clientContextFactoryRef = getClientContextFactoryRef(props.client);
  const constructorParameters = buildClientParameters(props.client);
  const args = Object.values(constructorParameters).map(p => p.refkey);
  return _$createComponent(ts.ClassMethod, {
    name: "constructor",
    parameters: constructorParameters,
    get children() {
      return [clientContextFieldRef, " =", " ", _$createComponent(ts.FunctionCallExpression, {
        target: clientContextFactoryRef,
        args: args
      }), ";", _$createIntrinsic("br", {}), _$createComponent(ay.For, {
        each: subClients,
        joiner: ";",
        hardline: true,
        children: subClient => {
          const subClientFieldRef = getSubClientClassFieldRef(subClient);
          const subClientArgs = calculateSubClientArgs(subClient, constructorParameters);
          return [subClientFieldRef, " = ", _$createComponent(NewClientExpression, {
            client: subClient,
            args: subClientArgs
          }), ";"];
        }
      })];
    }
  });
}
function calculateSubClientArgs(subClient, parentParams) {
  const subClientParams = buildClientParameters(subClient).map(p => p.name);
  return parentParams.filter(({
    name
  }) => subClientParams.includes(name)).flatMap(p => p.refkey ? p.refkey : []);
}
function NewClientExpression(props) {
  const clientConstructorRef = getClientClassRef(props.client);
  return ["new ", _$createComponent(ts.FunctionCallExpression, {
    target: clientConstructorRef,
    get args() {
      return props.args;
    }
  })];
}