import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import { code } from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { EncodingProvider } from "./encoding-provider.js";
import { HttpRequestParametersExpression } from "./http-request-parameters-expression.js";
import { getOperationOptionsParameterRefkey } from "./operation-parameters.js";
import { OperationTransformExpression } from "./transforms/operation-transform-expression.js";
export function HttpRequestOptions(props) {
  return _$createComponent(ts.VarDeclaration, {
    name: "httpRequestOptions",
    get refkey() {
      return props.refkey;
    },
    get children() {
      return _$createComponent(ts.ObjectExpression, {
        get children() {
          return [_$createComponent(HttpRequestOptions.Headers, {
            get httpOperation() {
              return props.httpOperation;
            }
          }), _$createComponent(HttpRequestOptions.Body, {
            get httpOperation() {
              return props.httpOperation;
            }
          })];
        }
      });
    }
  });
}
HttpRequestOptions.Headers = function HttpRequestOptionsHeaders(props) {
  // Extract the header request parameters from the operation
  const httpOperation = props.httpOperation;
  const headers = props.httpOperation.parameters.properties.filter(p => p.kind === "header" || p.kind === "contentType");
  const optionsParam = getOperationOptionsParameterRefkey(props.httpOperation);
  return _$createComponent(EncodingProvider, {
    defaults: {
      bytes: "base64",
      datetime: "rfc7231"
    },
    get children() {
      return _$createComponent(ts.ObjectProperty, {
        name: "headers",
        get children() {
          return [_$createComponent(HttpRequestParametersExpression, {
            parameters: headers,
            optionsParameter: optionsParam,
            httpOperation: httpOperation
          }), ","];
        }
      });
    }
  });
};
HttpRequestOptions.Body = function HttpRequestOptionsBody(props) {
  const body = props.httpOperation.parameters.body;
  if (!body) {
    return [];
  }
  // The transformer to apply to the body.
  const bodyTransform = [_$createComponent(OperationTransformExpression, {
    get httpOperation() {
      return props.httpOperation;
    }
  })];
  return [_$createComponent(ts.ObjectProperty, {
    name: "body",
    value: bodyTransform
  }), ","];
};
export function JSONSerializer(props) {
  return code`JSON.stringify(${props.children})`;
}