import { createComponent as _$createComponent, memo as _$memo, createIntrinsic as _$createIntrinsic } from "@alloy-js/core/jsx-runtime";
import { code, List, refkey, StatementList } from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { Reference } from "@alloy-js/typescript";
import { EncodingProvider } from "./encoding-provider.js";
import { uriTemplateLib } from "./external-packages/uri-template.js";
import { HttpRequestOptions } from "./http-request-options.js";
import { HttpRequestParametersExpression } from "./http-request-parameters-expression.js";
import { getOperationOptionsParameterRefkey } from "./operation-parameters.js";
export function HttpRequest(props) {
  const operationUrlRefkey = refkey();
  const requestOptionsRefkey = refkey();
  const httpResponseRefkey = props.responseRefkey ?? refkey();
  const verb = props.httpOperation.verb;
  return _$createComponent(List, {
    get children() {
      return [_$createComponent(StatementList, {
        get children() {
          return [_$createComponent(HttpRequest.Url, {
            get httpOperation() {
              return props.httpOperation;
            },
            refkey: operationUrlRefkey
          }), _$createComponent(HttpRequestOptions, {
            get httpOperation() {
              return props.httpOperation;
            },
            refkey: requestOptionsRefkey
          }), _$createComponent(ts.VarDeclaration, {
            name: "response",
            refkey: httpResponseRefkey,
            get children() {
              return code`
      await client.pathUnchecked(${_$createComponent(Reference, {
                refkey: operationUrlRefkey
              })}).${verb}(${_$createComponent(Reference, {
                refkey: requestOptionsRefkey
              })})
      `;
            }
          }), _$createIntrinsic("hbr", {})];
        }
      }), code`      
      if (typeof options?.operationOptions?.onResponse === "function") {
        options?.operationOptions?.onResponse(response);
      }`];
    }
  });
}
HttpRequest.Url = function HttpUrlDeclaration(props) {
  const urlTemplate = props.httpOperation.uriTemplate;
  const urlParameters = props.httpOperation.parameters.properties.filter(p => p.kind === "path" || p.kind === "query");
  const optionsParameter = getOperationOptionsParameterRefkey(props.httpOperation);
  return _$createComponent(EncodingProvider, {
    defaults: {
      bytes: "base64url"
    },
    get children() {
      return _$createComponent(ts.VarDeclaration, {
        name: "path",
        get refkey() {
          return props.refkey;
        },
        get children() {
          return [_$memo(() => uriTemplateLib.parse), "(", _$memo(() => JSON.stringify(urlTemplate)), ").expand(", _$memo(() => _$createComponent(HttpRequestParametersExpression, {
            get httpOperation() {
              return props.httpOperation;
            },
            optionsParameter: optionsParameter,
            parameters: urlParameters
          })), ")"];
        }
      });
    }
  });
};