import { createComponent as _$createComponent, memo as _$memo } from "@alloy-js/core/jsx-runtime";
import { code, For, List } from "@alloy-js/core";
import { isVoidType } from "@typespec/compiler";
import { useTsp } from "@typespec/emitter-framework";
import { getCreateRestErrorRefkey } from "./static-helpers/rest-error.js";
import { ContentTypeEncodingProvider } from "./transforms/content-type-encoding-provider.js";
import { JsonTransform } from "./transforms/json/json-transform.js";
export function HttpResponse(props) {
  return _$createComponent(List, {
    hardline: true,
    get children() {
      return [_$createComponent(HttpResponses, {
        get httpOperation() {
          return props.httpOperation;
        }
      }), _$memo(() => code`throw ${getCreateRestErrorRefkey()}(response);`)];
    }
  });
}
export function HttpResponses(props) {
  const {
    $
  } = useTsp();
  // Handle response by status code and content type
  const responses = $.httpOperation.flattenResponses(props.httpOperation);
  return _$createComponent(For, {
    get each() {
      return responses.filter(r => !$.httpResponse.isErrorResponse(r));
    },
    children: ({
      statusCode,
      contentType,
      responseContent,
      type
    }) => {
      const body = responseContent.body;
      let expression = code`return;`;
      const contentTypeCheck = body ? ` && response.headers["content-type"]?.includes("${contentType}")` : " && !response.body";
      if (body && (body.bodyKind === "single" || type && !isVoidType(type))) {
        expression = _$createComponent(ContentTypeEncodingProvider, {
          contentType: contentType,
          get children() {
            return ["return", " ", _$createComponent(JsonTransform, {
              itemRef: "response.body",
              target: "application",
              get type() {
                return body.type;
              }
            }), "!;"];
          }
        });
      }
      if ($.httpResponse.statusCode.isSingle(statusCode)) {
        return code`
      if (+response.status === ${statusCode}${contentTypeCheck}) {
        ${expression}
      }
      `;
      }
      if ($.httpResponse.statusCode.isRange(statusCode)) {
        return code`
      if (+response.status >= ${statusCode.start} && +response.status <= ${statusCode.end} ${contentTypeCheck}) {
        ${expression}
      }
      `;
      }
      return null;
    }
  });
}