import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import { ClientOperation as DefaultOperationComponent } from "../client-operation.js";
/**
 * Component that manages the operation handler pipeline.
 * It will try each handler in order until it finds one that can handle the operation.
 * If no handler is found, it will use the default ClientOperation component.
 */
export function OperationPipeline({
  httpOperation,
  pipeline,
  internal
}) {
  for (const handler of pipeline.handlers) {
    if (handler.canHandle(httpOperation)) {
      return handler.handle(httpOperation);
    }
  }

  // Default to standard client operation if no handler matched
  const defaultOperationRefkey = ay.refkey(httpOperation.operation);
  return _$createComponent(DefaultOperationComponent, {
    httpOperation: httpOperation,
    internal: internal,
    refkey: defaultOperationRefkey
  });
}