import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import { useTsp } from "@typespec/emitter-framework";
import { ScalarDataTransform } from "../data-transform.js";
import { getJsonArrayTransformRefkey, JsonArrayTransform, JsonArrayTransformDeclaration } from "./json-array-transform.js";
import { JsonModelPropertyTransform } from "./json-model-property-transform.js";
import { getJsonModelTransformRefkey, JsonModelTransform, JsonModelTransformDeclaration } from "./json-model-transform.js";
import { getJsonRecordTransformRefkey, JsonRecordTransform, JsonRecordTransformDeclaration } from "./json-record-transform.js";
import { getJsonUnionTransformRefkey, JsonUnionTransform, JsonUnionTransformDeclaration } from "./union-transform.js";
export function JsonTransform(props) {
  const {
    $
  } = useTsp();
  const type = $.httpPart.unpack(props.type) ?? props.type;
  const declaredTransform = getTransformReference(type, props.target);
  if (declaredTransform) {
    return ay.code`${declaredTransform}(${props.itemRef})`;
  }
  switch (type.kind) {
    case "Model":
      {
        if ($.array.is(type)) {
          return _$createComponent(JsonArrayTransform, {
            type: type,
            get itemRef() {
              return props.itemRef;
            },
            get target() {
              return props.target;
            }
          });
        }
        if ($.record.is(type)) {
          return _$createComponent(JsonRecordTransform, {
            type: type,
            get itemRef() {
              return props.itemRef;
            },
            get target() {
              return props.target;
            }
          });
        }
        return _$createComponent(JsonModelTransform, {
          type: type,
          get itemRef() {
            return props.itemRef;
          },
          get target() {
            return props.target;
          }
        });
      }
    case "Union":
      return _$createComponent(JsonUnionTransform, {
        type: type,
        get itemRef() {
          return props.itemRef;
        },
        get target() {
          return props.target;
        }
      });
    case "ModelProperty":
      {
        return _$createComponent(JsonModelPropertyTransform, {
          type: type,
          get itemRef() {
            return props.itemRef;
          },
          get target() {
            return props.target;
          }
        });
      }
    case "Scalar":
      {
        return _$createComponent(ScalarDataTransform, {
          type: type,
          get itemRef() {
            return props.itemRef;
          },
          get target() {
            return props.target;
          }
        });
      }
    default:
      return props.itemRef;
  }
}
export function JsonTransformDeclaration(props) {
  const {
    $
  } = useTsp();
  if (!$.model.is(props.type) && !$.union.is(props.type)) {
    return null;
  }
  if ($.model.is(props.type)) {
    if ($.array.is(props.type)) {
      return _$createComponent(JsonArrayTransformDeclaration, {
        get target() {
          return props.target;
        },
        get type() {
          return props.type;
        }
      });
    }
    if ($.record.is(props.type)) {
      return _$createComponent(JsonRecordTransformDeclaration, {
        get target() {
          return props.target;
        },
        get type() {
          return props.type;
        }
      });
    }
    return _$createComponent(JsonModelTransformDeclaration, {
      get type() {
        return props.type;
      },
      get target() {
        return props.target;
      }
    });
  }
  if ($.union.is(props.type)) {
    return _$createComponent(JsonUnionTransformDeclaration, {
      get target() {
        return props.target;
      },
      get type() {
        return props.type;
      }
    });
  }
}
function getTransformReference(type, target) {
  const {
    $
  } = useTsp();
  if (type.kind === "Model" && Boolean(type.name)) {
    if ($.array.is(type)) {
      return getJsonArrayTransformRefkey(type, target);
    }
    if ($.record.is(type)) {
      return getJsonRecordTransformRefkey(type, target);
    }
    return getJsonModelTransformRefkey(type, target);
  }
  if (type.kind === "Union" && Boolean(type.name)) {
    return getJsonUnionTransformRefkey(type, target);
  }
  return undefined;
}